<template>
  <div :id="id" class="flow-history">
    <template
      v-if="field.displayType == Constant.PermissionType_HIDDEN || field.textType == 'hidden'"
    >
      <!-- 隐藏 TODO:注意，隐藏时不应该有hidden的field存在，有安全问题，以后要改过来：Jarod -->
      <input type="hidden" v-model="field.value" />
      <div v-if="field.mobile&&field.hiddenValue">
        <div class="titleName">
          {{field.discript?field.discript:field.name}}
        </div>
        <div class="view-li">
          <div class="view-li-right">
            {{field.hiddenValue}}
          </div>
        </div>
      </div>
    </template>
    
    <!--只读-->
    <template v-else-if="field.textType == 'readonly' || field.displayType == Constant.PermissionType_READONLY || field.displayType == Constant.PermissionType_DISABLED">
      <template v-if="field.readOnlyShowValOnly">
        <!-- 只读（文本模式） -->
        <div class="titleName" v-if="field.mobile">
          {{field.discript?field.discript:field.name}}
        </div>
        <div :data="tableData" v-if="field.mobile">
          <div v-for="(item, index) in tableData" :key="index" class="view-li">
            <div class="view-li-right">
              <div class="reminder-nodeName">{{$t('startNodeName')}}：{{item.startNodeName}}</div>
              <div class="reminder-targetNode">{{$t('targetNodeName')}}：{{item.targetNodeName}}</div>
              <div class="reminder-transactor">{{$t('auditorName')}}：{{item.auditorName}}</div>
              <div class="reminder-action">{{$t('signingAction')}}：{{item.signingAction}}</div>
              <div class="reminder-opinion">{{$t('attitude')}}：{{item.attitude}}<img :src="item.signatureImageDate" style="height:32px;"></div>
              <div class="reminder-time">{{$t('processtime')}}：{{item.processtime}}</div>
            </div>
          </div>
        </div>
      </template>
      <template v-else>
        <!-- 只读（控件模式） -->
        <div class="titleName" v-if="field.mobile">
          {{field.discript?field.discript:field.name}}
        </div>
        <div :data="tableData" v-if="field.mobile">
          <div v-for="(item,index) in tableData" :key="index" class="view-li">
            <div class="view-li-right">
              <div class="reminder-nodeName">{{$t('startNodeName')}}：{{item.startNodeName}}</div>
              <div class="reminder-targetNode">{{$t('targetNodeName')}}：{{item.targetNodeName}}</div>
              <div class="reminder-transactor">{{$t('auditorName')}}：{{item.auditorName}}</div>
              <div class="reminder-action">{{$t('signingAction')}}：{{item.signingAction}}</div>
              <div class="reminder-opinion">{{$t('attitude')}}：{{item.attitude}}<img :src="item.signatureImageDate" style="height:32px;"></div>
              <div class="reminder-time">{{$t('processtime')}}：{{item.processtime}}</div>
            </div>
          </div>
        </div>
      </template>
    </template>

    <template v-else-if="field.displayType == Constant.PermissionType_MODIFY">
      <!-- 可编辑 -->
      <div class="titleName" v-if="field.mobile">
        {{field.discript?field.discript:field.name}}
      </div>
      <div :data="tableData" v-if="field.mobile">
        <div v-for="(item, index) in tableData" :key="index" class="view-li">
          <div class="view-li-right">
            <div class="reminder-nodeName">{{$t('startNodeName')}}：{{item.startNodeName}}</div>
            <div class="reminder-targetNode">{{$t('targetNodeName')}}：{{item.targetNodeName}}</div>
            <div class="reminder-transactor">{{$t('auditorName')}}：{{item.auditorName}}</div>
            <div class="reminder-action">{{$t('signingAction')}}：{{item.signingAction}}</div>
            <div class="reminder-opinion">{{$t('attitude')}}：{{item.attitude}}<img :src="item.signatureImageDate" style="height:32px;"></div>
            <div class="reminder-time">{{$t('processtime')}}：{{item.processtime}}</div>
          </div>
        </div>
      </div>
    </template>
  </div>
</template>

<script>
import Constant from "@/Constant.js"
import API from "@/api.js"
import controlHidden from "@/assets/js/controlHidden.js"
export default {
  name: "o-flow-history",
  props: ["id"],
  computed: {
    field: function() {
      return this.$parent.findField(this.id);
    },
  },
  mounted(){
    this.getFlowHistory();
    this.$nextTick(()=>{
      let field = this.field;
      if(field.isHideType) {
        let id = this.id,
          formShowType = field.formShowType;
        controlHidden({id, field, formShowType})
      }
    })
  },
  methods: {
    getFlowHistory(){
      let appId = this.$root.appid;
      let docId = this.field.docId;
      API.getFlowHistorys(
        appId,
        docId,
        {
          onSucess: response => {
            let flowData = response.data.data
            flowData.forEach(item => {
              switch (item.flowOperation) {
                case '7':
                  item.signingAction = "流转";
                  break;
                case '8':
                  item.signingAction = "终止";
                  break;
                case "80": 
                  item.signingAction = "流转";
                  break;
                case "81":
                  item.signingAction = "回退";
                  break;
                case "85": 
                  item.signingAction = "回撤";
                  break;
                case "86": 
                  item.signingAction = "干预";
                  break;
                case "87": 
                  item.signingAction = "过期";
                  break;
                case "88": 
                  item.signingAction = "挂起";
                  break;
                case "89": 
                  item.signingAction = "恢复";
                  break;
                case "90": 
                  item.signingAction = "跳过";
                  break;
                case "91":
                  item.signingAction = "会签";
                  break;
                default:
                  break;
              }
            });
            this.tableData = flowData;
          }
        }
      )
    }
  },
  data: function() {
    return {
      Constant,
      tableData:[],
    };
  }
}
</script>
